@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,11 +68,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Amzer keitat Greenwich (AKG)",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Apia = new String[] {
                "eur c\u02bchoa\u00f1v Apia",
@@ -92,11 +92,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "eur c\u02bchoa\u00f1v Kuba",
-               "",
+               "CST",
                "eur ha\u00f1v Kuba",
-               "",
+               "CDT",
                "eur Kuba",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "eur c\u02bchoa\u00f1v Fidji",
@@ -180,11 +180,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "eur c\u02bchoa\u00f1v Sina",
-               "",
+               "CST",
                "eur ha\u00f1v Sina",
-               "",
+               "CDT",
                "eur Sina",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "eur Inizi Kokoz",
@@ -212,19 +212,19 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "eur c\u02bchoa\u00f1v Japan",
-               "",
+               "JST",
                "eur ha\u00f1v Japan",
-               "",
+               "JDT",
                "eur Japan",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "eur c\u02bchoa\u00f1v Korea",
-               "",
+               "KST",
                "eur ha\u00f1v Korea",
-               "",
+               "KST",
                "eur Korea",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "eur Nauru",
@@ -252,11 +252,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "eur c\u02bchoa\u00f1v Samoa",
-               "",
+               "SST",
                "eur ha\u00f1v Samoa",
-               "",
+               "SST",
                "eur Samoa",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "eur Syowa",
@@ -276,11 +276,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "eur c\u02bchoa\u00f1v Alaska",
-               "",
+               "AKST",
                "eur ha\u00f1v Alaska",
-               "",
+               "AKDT",
                "eur Alaska",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "eur c\u02bchoa\u00f1v an Amazon",
@@ -340,11 +340,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "eur c\u02bchoa\u00f1v Israel",
-               "",
+               "IST",
                "eur ha\u00f1v Israel",
-               "",
+               "IDT",
                "eur Israel",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "eur Kosrae",
@@ -364,11 +364,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "eur c\u02bchoa\u00f1v Moskov",
-               "",
+               "MSK",
                "eur ha\u00f1v Moskov",
-               "",
+               "MSK",
                "eur Moskov",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "eur Pohnpei",
@@ -388,11 +388,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "eur c\u02bchoa\u00f1v Taipei",
-               "",
+               "CST",
                "eur ha\u00f1v Taipei",
-               "",
+               "CDT",
                "eur Taipei",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "eur Tuvalu",
@@ -580,11 +580,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "eur c\u02bchoa\u00f1v an Atlantel",
-               "",
+               "AST",
                "eur ha\u00f1v an Atlantel",
-               "",
+               "ADT",
                "eur an Atlantel",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "eur c\u02bchoa\u00f1v Bras\u00edlia",
@@ -596,11 +596,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "eur Chamorro",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "eur c\u02bchoa\u00f1v Kolombia",
@@ -644,11 +644,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "eur c\u02bchoa\u00f1v Pakistan",
-               "",
+               "PKT",
                "eur ha\u00f1v Pakistan",
-               "",
+               "PKST",
                "eur Pakistan",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "eur c\u02bchoa\u00f1v Paraguay",
@@ -708,11 +708,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "eur c\u02bchoa\u00f1v Hong Kong",
-               "",
+               "HKT",
                "eur ha\u00f1v Hong Kong",
-               "",
+               "HKST",
                "eur Hong Kong",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "eur Indez-Sina",
@@ -772,11 +772,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "eur c\u02bchoa\u00f1v Volgograd",
-               "",
+               "MSK",
                "eur ha\u00f1v Volgograd",
-               "",
+               "MSK",
                "eur Volgograd",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "eur c\u02bchoa\u00f1v Azerbaidjan",
@@ -852,11 +852,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "eur c\u02bchoa\u00f1v Zeland-Nevez",
-               "",
+               "NZST",
                "eur ha\u00f1v Zeland-Nevez",
-               "",
+               "NZDT",
                "eur Zeland-Nevez",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "eur c\u02bchoa\u00f1v Novosibirsk",
@@ -868,11 +868,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "eur c\u02bchoa\u00f1v ar Filipinez",
-               "",
+               "PST",
                "eur ha\u00f1v ar Filipinez",
-               "",
+               "PDT",
                "eur ar Filipinez",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "eur c\u02bchoa\u00f1v Vladivostok",
@@ -900,11 +900,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "eur c\u02bchoa\u00f1v Newfoundland",
-               "",
+               "NST",
                "eur ha\u00f1v Newfoundland",
-               "",
+               "NDT",
                "eur Newfoundland",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "eur c\u02bchoa\u00f1v Turkmenistan",
@@ -948,27 +948,27 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "eur Kreizafrika",
+               "CAT",
                "",
+               "CAT",
                "",
-               "",
-               "",
-               "",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "eur Afrika ar Reter",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "eur c\u02bchoa\u00f1v Afrika ar C\u02bchorn\u00f4g",
-               "",
+               "WAT",
                "eur ha\u00f1v Afrika ar C\u02bchorn\u00f4g",
-               "",
+               "WAT",
                "eur Afrika ar C\u02bchorn\u00f4g",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "eur Dumont-d\u2019Urville",
@@ -980,67 +980,67 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "eur c\u02bchoa\u00f1v Kreizeuropa",
-               "",
+               "CET",
                "eur ha\u00f1v Kreizeuropa",
-               "",
+               "CEST",
                "eur Kreizeuropa",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "eur c\u02bchoa\u00f1v Europa ar Reter",
-               "",
+               "EET",
                "eur ha\u00f1v Europa ar Reter",
-               "",
+               "EEST",
                "eur Europa ar Reter",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "eur c\u02bchoa\u00f1v Europa ar C\u02bchorn\u00f4g",
-               "",
+               "WET",
                "eur ha\u00f1v Europa ar C\u02bchorn\u00f4g",
-               "",
+               "WEST",
                "eur Europa ar C\u02bchorn\u00f4g",
-               "",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "eur c\u02bchoa\u00f1v an Habask mec\u02bchikan",
-               "",
+               "MST",
                "eur ha\u00f1v an Habask mec\u02bchikan",
-               "",
+               "MDT",
                "eur an Habask mec\u02bchikan",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "eur c\u02bchoa\u00f1v Suafrika",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "eur c\u02bchoa\u00f1v ar C\u02bchreiz",
-               "",
+               "CST",
                "eur ha\u00f1v ar C\u02bchreiz",
-               "",
+               "CDT",
                "eur ar C\u02bchreiz",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "eur c\u02bchoa\u00f1v ar Reter",
-               "",
+               "EST",
                "eur ha\u00f1v ar Reter",
-               "",
+               "EST",
                "eur ar Reter",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "eur c\u02bchoa\u00f1v an Habask",
-               "",
+               "PST",
                "eur ha\u00f1v an Habask",
-               "",
+               "PDT",
                "eur an Habask",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "eur Douaro\u00f9 aostral Fra\u00f1s hag Antarktika",
@@ -1060,11 +1060,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "eur c\u02bchoa\u00f1v Hawaii hag an Aleouted",
-               "",
+               "HST",
                "eur ha\u00f1v Hawaii hag an Aleouted",
-               "",
+               "HST",
                "eur Hawaii hag an Aleouted",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "eur Inizi Phoenix",
@@ -1084,11 +1084,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "eur c\u02bchoa\u00f1v ar Menezio\u00f9",
-               "",
+               "MST",
                "eur ha\u00f1v ar Menezio\u00f9",
-               "",
+               "MST",
                "eur ar Menezio\u00f9",
-               "",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "eur Inizi Marshall",
@@ -1116,27 +1116,27 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "eur c\u02bchoa\u00f1v Kreizaostralia",
-               "",
+               "ACST",
                "eur ha\u00f1v Kreizaostralia",
-               "",
+               "ACDT",
                "eur Kreizaostralia",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "eur c\u02bchoa\u00f1v Aostralia ar Reter",
-               "",
+               "AEST",
                "eur ha\u00f1v Aostralia ar Reter",
-               "",
+               "AEDT",
                "eur Aostralia ar Reter",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "eur c\u02bchoa\u00f1v Aostralia ar C\u02bchorn\u00f4g",
-               "",
+               "AWST",
                "eur ha\u00f1v Aostralia ar C\u02bchorn\u00f4g",
-               "",
+               "AWDT",
                "eur Aostralia ar C\u02bchorn\u00f4g",
-               "",
+               "AWT",
             };
         final String[] Greenland_Eastern = new String[] {
                "eur c\u02bchoa\u00f1v Greunland ar Reter",
@@ -1156,27 +1156,27 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "eur Kreiz Indonezia",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "eur Indonezia ar Reter",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "eur Indonezia ar C\u02bchorn\u00f4g",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "eur Kazakstan ar Reter",
@@ -1364,11 +1364,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "Amzer keitat Greenwich (AKG)",
-                    "",
+                    "GMT",
                     "eur c\u02bchoa\u00f1v Iwerzhon",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1376,11 +1376,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Amzer keitat Greenwich (AKG)",
-                    "",
+                    "GMT",
                     "eur ha\u00f1v Breizh-Veur",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1435,11 +1435,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Amzer keitat Greenwich (AKG)",
-                    "",
+                    "GMT",
                     "eur ha\u00f1v Breizh-Veur",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1676,276 +1676,108 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Indiana/Tell_City", America_Central },
             { "America/Indiana/Vincennes", America_Eastern },
             { "Antarctica/DumontDUrville", DumontDUrville },
-            { "timezone.excity.Asia/Aden", "Aden" },
             { "timezone.excity.Asia/Baku", "Bakou" },
-            { "timezone.excity.Asia/Gaza", "Gaza" },
             { "America/Argentina/La_Rioja", Argentina },
             { "America/Argentina/San_Juan", Argentina },
             { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
-            { "timezone.excity.Asia/Amman", "Amman" },
             { "timezone.excity.Asia/Chita", "Tchita" },
             { "timezone.excity.Asia/Kabul", "Kaboul" },
             { "timezone.excity.Asia/Macau", "Macau" },
-            { "timezone.excity.Asia/Qatar", "Qatar" },
-            { "timezone.excity.Asia/Seoul", "Seoul" },
-            { "timezone.excity.Asia/Tokyo", "Tokyo" },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
-            { "timezone.excity.Africa/Juba", "Juba" },
             { "timezone.excity.Africa/Lome", "Lom\u00e9" },
-            { "timezone.excity.Asia/Almaty", "Almaty" },
             { "timezone.excity.Asia/Anadyr", "Anadyr\u02bc" },
             { "timezone.excity.Asia/Beirut", "Bayrut" },
-            { "timezone.excity.Asia/Brunei", "Brunei" },
             { "timezone.excity.Asia/Kuwait", "Koweit" },
-            { "timezone.excity.Asia/Manila", "Manila" },
             { "timezone.excity.Asia/Muscat", "Masqat" },
-            { "timezone.excity.Asia/Riyadh", "Riyadh" },
             { "timezone.excity.Asia/Saigon", "K\u00ear H\u00f4-Chi-Minh" },
-            { "timezone.excity.Asia/Taipei", "Taipei" },
-            { "timezone.excity.Asia/Tehran", "Tehran" },
             { "timezone.excity.Asia/Urumqi", "\u00dcr\u00fcmqi" },
             { "timezone.excity.Etc/Unknown", "k\u00ear dianav" },
             { "timezone.excity.Europe/Kiev", "Kiev" },
-            { "timezone.excity.Europe/Oslo", "Oslo" },
-            { "timezone.excity.Europe/Riga", "Riga" },
             { "timezone.excity.Europe/Rome", "Roma" },
-            { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Africa/Cairo", "Kaero" },
-            { "timezone.excity.Africa/Dakar", "Dakar" },
-            { "timezone.excity.Africa/Lagos", "Lagos" },
             { "timezone.excity.Africa/Tunis", "Tuniz" },
-            { "timezone.excity.America/Adak", "Adak" },
-            { "timezone.excity.America/Lima", "Lima" },
-            { "timezone.excity.Asia/Baghdad", "Baghdad" },
             { "timezone.excity.Asia/Bahrain", "Bahrein" },
-            { "timezone.excity.Asia/Bangkok", "Bangkok" },
-            { "timezone.excity.Asia/Bishkek", "Bishkek" },
             { "timezone.excity.Asia/Colombo", "Kolamba" },
-            { "timezone.excity.Asia/Irkutsk", "Irkutsk" },
-            { "timezone.excity.Asia/Jakarta", "Jakarta" },
-            { "timezone.excity.Asia/Karachi", "Karachi" },
             { "timezone.excity.Asia/Nicosia", "Levkos\u00eda" },
-            { "timezone.excity.Asia/Tbilisi", "Tbilisi" },
-            { "timezone.excity.Asia/Thimphu", "Thimphu" },
-            { "timezone.excity.Asia/Yakutsk", "Yakutsk" },
-            { "timezone.excity.Asia/Yerevan", "Yerevan" },
-            { "timezone.excity.Europe/Malta", "Malta" },
             { "timezone.excity.Europe/Minsk", "Mensk" },
             { "timezone.excity.Europe/Paris", "Pariz" },
-            { "timezone.excity.Europe/Sofia", "Sofia" },
-            { "timezone.excity.Europe/Vaduz", "Vaduz" },
             { "timezone.excity.Indian/Cocos", "Kokoz" },
-            { "timezone.excity.Pacific/Apia", "Apia" },
             { "timezone.excity.Pacific/Fiji", "Fidji" },
-            { "timezone.excity.Pacific/Guam", "Guam" },
-            { "timezone.excity.Pacific/Niue", "Niue" },
-            { "timezone.excity.Africa/Bamako", "Bamako" },
-            { "timezone.excity.Africa/Bangui", "Bangui" },
-            { "timezone.excity.Africa/Banjul", "Banjul" },
-            { "timezone.excity.Africa/Bissau", "Bissau" },
-            { "timezone.excity.Africa/Harare", "Harare" },
-            { "timezone.excity.Africa/Kigali", "Kigali" },
-            { "timezone.excity.Africa/Luanda", "Luanda" },
-            { "timezone.excity.Africa/Lusaka", "Lusaka" },
-            { "timezone.excity.Africa/Malabo", "Malabo" },
-            { "timezone.excity.Africa/Maputo", "Maputo" },
-            { "timezone.excity.Africa/Maseru", "Maseru" },
-            { "timezone.excity.Africa/Niamey", "Niamey" },
-            { "timezone.excity.America/Aruba", "Aruba" },
             { "timezone.excity.America/Belem", "Bel\u00e9m" },
             { "timezone.excity.America/Thule", "Q\u00e2n\u00e2q" },
-            { "timezone.excity.Asia/Ashgabat", "Ashgabat" },
             { "timezone.excity.Asia/Calcutta", "Calcutta" },
             { "timezone.excity.Asia/Damascus", "Damask" },
-            { "timezone.excity.Asia/Dushanbe", "Dushanbe" },
-            { "timezone.excity.Asia/Jayapura", "Jayapura" },
-            { "timezone.excity.Asia/Sakhalin", "Sakhalin" },
-            { "timezone.excity.Asia/Shanghai", "Shanghai" },
             { "timezone.excity.Asia/Tashkent", "Toshkent" },
             { "timezone.excity.Europe/Athens", "Aten" },
-            { "timezone.excity.Europe/Berlin", "Berlin" },
             { "timezone.excity.Europe/Dublin", "Dulenn" },
             { "timezone.excity.Europe/Jersey", "Jerzenez" },
             { "timezone.excity.Europe/Lisbon", "Lisboa" },
             { "timezone.excity.Europe/London", "Londrez" },
-            { "timezone.excity.Europe/Madrid", "Madrid" },
-            { "timezone.excity.Europe/Monaco", "Monaco" },
             { "timezone.excity.Europe/Moscow", "Moskov" },
             { "timezone.excity.Europe/Prague", "Praha" },
-            { "timezone.excity.Europe/Skopje", "Skopje" },
             { "timezone.excity.Europe/Tirane", "Tiran\u00eb" },
-            { "timezone.excity.Europe/Vienna", "Vienna" },
             { "timezone.excity.Europe/Warsaw", "Varsovia" },
-            { "timezone.excity.Europe/Zagreb", "Zagreb" },
-            { "timezone.excity.Indian/Chagos", "Chagos" },
             { "timezone.excity.Indian/Comoro", "Komorez" },
-            { "timezone.excity.Pacific/Nauru", "Nauru" },
-            { "timezone.excity.Pacific/Palau", "Palau" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
-            { "timezone.excity.Africa/Abidjan", "Abidjan" },
             { "timezone.excity.Africa/Algiers", "Aljer" },
-            { "timezone.excity.Africa/Conakry", "Conakry" },
-            { "timezone.excity.Africa/Kampala", "Kampala" },
-            { "timezone.excity.Africa/Mbabane", "Mbabane" },
-            { "timezone.excity.Africa/Nairobi", "Nairobi" },
             { "timezone.excity.Africa/Tripoli", "Tarabulus (Tripoli)" },
-            { "timezone.excity.America/Belize", "Belize" },
             { "timezone.excity.America/Bogota", "Bogot\u00e1" },
-            { "timezone.excity.America/Cayman", "Cayman" },
-            { "timezone.excity.America/Denver", "Denver" },
-            { "timezone.excity.America/Guyana", "Guyana" },
             { "timezone.excity.America/Havana", "La Habana" },
-            { "timezone.excity.America/Inuvik", "Inuvik" },
-            { "timezone.excity.America/La_Paz", "La Paz" },
-            { "timezone.excity.America/Manaus", "Manaus" },
-            { "timezone.excity.America/Nassau", "Nassau" },
             { "timezone.excity.America/Panama", "Panam\u00e1" },
-            { "timezone.excity.America/Recife", "Recife" },
-            { "timezone.excity.Asia/Hong_Kong", "Hong Kong" },
             { "timezone.excity.Asia/Jerusalem", "Jeruzalem" },
             { "timezone.excity.Asia/Kamchatka", "Kamtchatka" },
             { "timezone.excity.Asia/Pyongyang", "P\u02bcyongyang" },
             { "timezone.excity.Asia/Singapore", "Singapour" },
             { "timezone.excity.Asia/Vientiane", "Viangchan" },
-            { "timezone.excity.Europe/Andorra", "Andorra" },
-            { "timezone.excity.Europe/Tallinn", "Tallinn" },
             { "timezone.excity.Europe/Vatican", "Vatikan" },
-            { "timezone.excity.Europe/Vilnius", "Vilnius" },
-            { "timezone.excity.Indian/Mayotte", "Mayotte" },
             { "timezone.excity.Indian/Reunion", "Re\u00fcnion" },
             { "timezone.excity.Pacific/Easter", "Enez Pask" },
-            { "timezone.excity.Pacific/Midway", "Midway" },
-            { "timezone.excity.Pacific/Noumea", "Noumea" },
-            { "timezone.excity.Pacific/Tahiti", "Tahiti" },
-            { "timezone.excity.Pacific/Wallis", "Wallis" },
-            { "timezone.excity.Africa/Djibouti", "Djibouti" },
             { "timezone.excity.Africa/El_Aaiun", "La\u02bcYoun" },
-            { "timezone.excity.Africa/Freetown", "Freetown" },
-            { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "timezone.excity.Africa/Khartoum", "Khartoum" },
-            { "timezone.excity.Africa/Kinshasa", "Kinshasa" },
-            { "timezone.excity.Africa/Monrovia", "Monrovia" },
             { "timezone.excity.Africa/Ndjamena", "N\u02bcDjamena" },
-            { "timezone.excity.Africa/Sao_Tome", "S\u00e3o Tom\u00e9" },
-            { "timezone.excity.Africa/Windhoek", "Windhoek" },
-            { "timezone.excity.America/Antigua", "Antigua" },
-            { "timezone.excity.America/Caracas", "Caracas" },
-            { "timezone.excity.America/Cayenne", "Cayenne" },
-            { "timezone.excity.America/Chicago", "Chicago" },
             { "timezone.excity.America/Godthab", "Nuuk (Godth\u00e5b)" },
-            { "timezone.excity.America/Grenada", "Grenada" },
             { "timezone.excity.America/Jamaica", "Jamaika" },
-            { "timezone.excity.America/Managua", "Managua" },
             { "timezone.excity.Asia/Phnom_Penh", "Phnum P\u00e9nh" },
             { "timezone.excity.Atlantic/Azores", "Azorez" },
             { "timezone.excity.Atlantic/Canary", "Kanariez" },
             { "timezone.excity.Atlantic/Faeroe", "Faero" },
-            { "timezone.excity.Australia/Perth", "Perth" },
             { "timezone.excity.Europe/Belgrade", "Beograd" },
             { "timezone.excity.Europe/Brussels", "Brusel" },
-            { "timezone.excity.Europe/Budapest", "Budapest" },
-            { "timezone.excity.Europe/Chisinau", "Chisinau" },
             { "timezone.excity.Europe/Guernsey", "Gwernenez" },
-            { "timezone.excity.Europe/Helsinki", "Helsinki" },
-            { "timezone.excity.Europe/Istanbul", "Istanbul" },
-            { "timezone.excity.Europe/Sarajevo", "Sarajevo" },
             { "timezone.excity.Indian/Maldives", "Maldivez" },
-            { "timezone.excity.Pacific/Chatham", "Chatham" },
-            { "timezone.excity.Pacific/Gambier", "Gambier" },
-            { "timezone.excity.Pacific/Norfolk", "Norfolk" },
-            { "timezone.excity.Africa/Bujumbura", "Bujumbura" },
             { "timezone.excity.Africa/Mogadishu", "Muqdisho" },
-            { "timezone.excity.America/Anguilla", "Anguilla" },
-            { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
-            { "timezone.excity.America/Barbados", "Barbados" },
-            { "timezone.excity.America/Dominica", "Dominica" },
-            { "timezone.excity.America/Edmonton", "Edmonton" },
             { "timezone.excity.America/Miquelon", "Mikelon" },
-            { "timezone.excity.America/New_York", "New York" },
-            { "timezone.excity.America/Santiago", "Santiago" },
             { "timezone.excity.America/St_Johns", "Saint John\u02bcs" },
             { "timezone.excity.America/St_Kitts", "Saint Kitts" },
             { "timezone.excity.America/St_Lucia", "Saint Lucia" },
-            { "timezone.excity.America/Winnipeg", "Winnipeg" },
-            { "timezone.excity.Asia/Novosibirsk", "Novosibirsk" },
-            { "timezone.excity.Asia/Ulaanbaatar", "Ulaanbaatar" },
-            { "timezone.excity.Asia/Vladivostok", "Vladivostok" },
             { "timezone.excity.Atlantic/Bermuda", "Bermudez" },
-            { "timezone.excity.Atlantic/Madeira", "Madeira" },
-            { "timezone.excity.Australia/Darwin", "Darwin" },
-            { "timezone.excity.Australia/Sydney", "Sydney" },
-            { "timezone.excity.Europe/Amsterdam", "Amsterdam" },
             { "timezone.excity.Europe/Bucharest", "Bukarest" },
             { "timezone.excity.Europe/Gibraltar", "Jibraltar" },
-            { "timezone.excity.Europe/Ljubljana", "Ljubljana" },
             { "timezone.excity.Europe/Mariehamn", "Marjehamn" },
-            { "timezone.excity.Europe/Podgorica", "Podgorica" },
-            { "timezone.excity.Europe/Stockholm", "Stockholm" },
-            { "timezone.excity.Europe/Volgograd", "Volgograd" },
-            { "timezone.excity.Indian/Christmas", "Christmas" },
             { "timezone.excity.Indian/Kerguelen", "Kergelenn" },
             { "timezone.excity.Indian/Mauritius", "Moris" },
-            { "timezone.excity.Pacific/Auckland", "Auckland" },
             { "timezone.excity.Pacific/Honolulu", "Honolulu" },
-            { "timezone.excity.Pacific/Pitcairn", "Pitcairn" },
             { "timezone.excity.Africa/Casablanca", "Dar el Beida (Casablanca)" },
-            { "timezone.excity.Africa/Libreville", "Libreville" },
-            { "timezone.excity.Africa/Lubumbashi", "Lubumbashi" },
-            { "timezone.excity.Africa/Nouakchott", "Nouakchott" },
-            { "timezone.excity.Africa/Porto-Novo", "Porto-Novo" },
-            { "timezone.excity.America/Anchorage", "Anchorage" },
-            { "timezone.excity.America/Guatemala", "Guatemala" },
-            { "timezone.excity.America/Monterrey", "Monterrey" },
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
-            { "timezone.excity.America/Vancouver", "Vancouver" },
-            { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lumpur" },
-            { "timezone.excity.Europe/Bratislava", "Bratislava" },
             { "timezone.excity.Europe/Copenhagen", "Kopenhagen" },
             { "timezone.excity.Europe/Luxembourg", "Luksembourg" },
-            { "timezone.excity.Europe/San_Marino", "San Marino" },
             { "timezone.excity.Pacific/Galapagos", "Gal\u00e1pagos" },
             { "timezone.excity.Pacific/Marquesas", "Markiz" },
-            { "timezone.excity.Pacific/Pago_Pago", "Pago Pago" },
-            { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Africa/Addis_Ababa", "Adis Abeba" },
-            { "timezone.excity.Africa/Brazzaville", "Brazzaville" },
-            { "timezone.excity.Africa/Ouagadougou", "Ouagadougou" },
-            { "timezone.excity.America/Costa_Rica", "Costa Rica" },
             { "timezone.excity.America/Guadeloupe", "Gwadeloup" },
             { "timezone.excity.America/Martinique", "Martinik" },
-            { "timezone.excity.America/Montevideo", "Montevideo" },
-            { "timezone.excity.America/Montserrat", "Montserrat" },
-            { "timezone.excity.America/Paramaribo", "Paramaribo" },
             { "timezone.excity.America/St_Vincent", "Sant Visant" },
             { "timezone.excity.Asia/Yekaterinburg", "Yekaterinbourg" },
             { "timezone.excity.Atlantic/Reykjavik", "Reykjav\u00edk" },
             { "timezone.excity.Atlantic/St_Helena", "Saint Helena" },
-            { "timezone.excity.Australia/Adelaide", "Adelaide" },
-            { "timezone.excity.Australia/Brisbane", "Brisbane" },
             { "timezone.excity.Europe/Isle_of_Man", "Manav" },
-            { "timezone.excity.Europe/Kaliningrad", "Kaliningrad" },
-            { "timezone.excity.Africa/Johannesburg", "Johannesburg" },
             { "timezone.excity.America/El_Salvador", "Salvador" },
-            { "timezone.excity.America/Los_Angeles", "Los Angeles" },
             { "timezone.excity.America/Mexico_City", "K\u00ear Vec\u02bchiko" },
-            { "timezone.excity.America/Puerto_Rico", "Puerto Rico" },
-            { "timezone.excity.America/Tegucigalpa", "Tegucigalpa" },
-            { "timezone.excity.Arctic/Longyearbyen", "Longyearbyen" },
             { "timezone.excity.Atlantic/Cape_Verde", "Kab Glas" },
-            { "timezone.excity.Australia/Melbourne", "Melbourne" },
-            { "timezone.excity.Indian/Antananarivo", "Antananarivo" },
-            { "timezone.excity.Africa/Dar_es_Salaam", "Dar es Salaam" },
-            { "timezone.excity.America/Buenos_Aires", "Buenos Aires" },
-            { "timezone.excity.Antarctica/Macquarie", "Macquarie" },
-            { "timezone.excity.Pacific/Bougainville", "Bougainville" },
-            { "timezone.excity.Pacific/Port_Moresby", "Port Moresby" },
-            { "timezone.excity.America/Port_of_Spain", "Port of Spain" },
             { "timezone.excity.America/St_Barthelemy", "Saint Barth\u00e9lemy" },
-            { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "timezone.excity.Atlantic/South_Georgia", "Georgia ar Su" },
         };
         return data;
